@@ -1,9 +1,11 @@
+from typing import Dict, Union
+
 from nonebot.adapters import Bot, MessageSegment
 
-from ..utils import (
+from ..utils import AdapterNotSupported
+from ..abstract_factories import (
     CustomBuildFunc,
     SupportedAdapters,
-    AdapterNotSupported,
     MessageSegmentFactory,
     do_build_custom,
     extract_adapter_type,
@@ -15,7 +17,7 @@ class Custom(MessageSegmentFactory):
 
     def __init__(
         self,
-        ms_dict: dict[SupportedAdapters, MessageSegment | CustomBuildFunc],
+        ms_dict: Dict[SupportedAdapters, Union[MessageSegment, CustomBuildFunc]],
     ):
         """
         自定义 MessageSegment
