@@ -8,3 +8,11 @@ class AdapterNotSupported(Exception):
     def __init__(self, adapter_name: str) -> None:
         message = f'adapter "{adapter_name}" not supported'
         super().__init__(self, message)
+
+
+class NoBotFound(RuntimeError):
+    pass
+
+
+class FallbackToDefault(Exception):
+    pass
