@@ -1,3 +1,5 @@
+from typing import cast
+
 from nonebot.internal.adapter.bot import Bot
 
 from .exceptions import AdapterNotSupported
@@ -10,4 +12,4 @@ def extract_adapter_type(bot: Bot) -> SupportedAdapters:
         raise AdapterNotSupported(adapter_name)
 
     adapter_name = SupportedAdapters(adapter_name)
-    return adapter_name
+    return cast(SupportedAdapters, adapter_name)
